function SimpleSpeedo(){}

SimpleSpeedo.prototype.initialize = function(){
	
	
		//VARIABLES
	window.blink = "none";
	window.blinkOn = false;
	window.autoBlink = false;
	window.maxRange = 30;
	
    window.cruiseSpeed = 0;
	window.cruiseEnabled = false;
    window.speedMs = 0;
	
	window.finals = {
		autoBlink: "OFF"
	};
	
	
    this.canvas = $('<canvas height="53px"></canvas>').appendTo(this.rootElement).addClass('canvas');

    this.labelDiv = $('<center><div></div></center>').appendTo(this.rootElement).addClass('labelDiv');
    this.cruiseDiv = $('<center><div></div></center>').appendTo(this.rootElement).addClass('cruiseDiv');
	//Cruise Control ("+window.finals.cruiseControlState+")
    this.canvas.width = 200;
    this.canvas.height = 53;
	
	
    this.loaded = false;

    var self = this;
    this.labelDiv.click(function(){self.toggleUnit();});
    this.cruiseDiv.click(function(){self.toggleCruise();});

    //If no unit was previously selected, default to km/h
    if ((this.persistance.Unit != "MPH") && (this.persistance.Unit != "km/h")) this.persistance.Unit = "km/h";
};

SimpleSpeedo.prototype.toggleUnit = function(){
    //Toggle between MPH and km/h, save the option to persistance system
    this.persistance.Unit = this.persistance.Unit === 'MPH' ? 'km/h' : 'MPH';
    this.save();
};

SimpleSpeedo.prototype.toggleCruise = function(){
    //Toggle between MPH and km/h, save the option to persistance system
    window.cruiseEnabled ^= true;
	window.cruiseSpeed = speedMs;
    this.save();
};


SimpleSpeedo.prototype.update = function(streams){
	
    //Get the values to work with, do rounding and stuff as needed
    var speedMs = streams.electrics.wheelspeed;
    if (isNaN(speedMs)) speedMs = streams.electrics.airspeed;    //If no wheelspeedo present use airspeed

    var speedUnits;
    //Modify with selected units
    if(this.persistance.Unit == "MPH"){
        speedUnits = toInt(2.236*speedMs);
    } else {
        speedUnits = toInt(3.6*speedMs);
    }

    var speedStart;
    //for resetting scale >160
    if (speedUnits > 160) {
        speedStart = 160;
    } else {
        speedStart = 0;
    }

    //start canvas stuff
    var c = this.canvas[0];
    var ctx = c.getContext('2d');

    //clear before drawing stuff on canvas
    ctx.clearRect(0,0,200,53);

    //Make the bar
    if (speedStart === 0){
        ctx.fillStyle = "RGBA(0,0,255,0.5)";
    } else {
        ctx.fillStyle = "RGBA(255,0,255,0.5)";
    }
	
	//Speed Line
    ctx.fillRect(20,10,Math.min(speedUnits-speedStart, 160),25);
	
	//Cruise Control Line
    ctx.fillStyle = "RGBA(255,0,255,0.5)";
    ctx.fillRect(20 + Math.round(window.cruiseSpeed) - 1, 10, 2, 25);

    //text
    ctx.font='20px Arial';
    ctx.textAlign="center";

    ctx.fillStyle = "black";
    ctx.fillText(rSet(speedUnits, 3, "0"),100,30);

    //add border
    ctx.strokeRect(20,10,160,25);

    //Add labels
    //-Units
    this.labelDiv.html("Speed (" + this.persistance.Unit + ")");
    this.cruiseDiv.html("Cruise Control (" + window.finals.cruiseControlState + ") - " + window.cruiseSpeed + " mph");

    //-Numbers
    ctx.font='7px Arial';
    var interval = 20;
    for (var x=0; x<=160; x+=interval) {
        ctx.fillText(speedStart+x,x+20,48);
    }

    //Add Graduations
    //20px/20unit intervals
    for (var x1=20; x1<=180; x1+=interval) {
        ctx.beginPath();
        ctx.moveTo(x1, 35);
        ctx.lineTo(x1, 40);
        ctx.stroke();
    }
    //and 10px/10unit intervals
    for (var x2=30; x2<=180; x2+=interval) {
        ctx.beginPath();
        ctx.moveTo(x2, 35);
        ctx.lineTo(x2, 38);
        ctx.stroke();
    }
	
	
	
	//UPDATING STUFF (FOR MOD; NOTHING BELOW IS VISUAL!)
	var steer = streams.electrics.steering;
	var warncrash = Math.abs(streams.sensors.gx) + Math.abs(streams.sensors.gy);
		
    window.speedMs = Math.round(streams.electrics.wheelspeed*2.236);
	if(window.cruiseEnabled) {
		var maxThrottle = (window.cruiseSpeed - window.speedMs) / 5;
		var maxBrake = (window.speedMs - window.cruiseSpeed) / 5;
		console.log(window.cruiseSpeed - window.speedMs);
		beamng.sendActiveObjectLua("input.event('axisy0', "+maxThrottle+", 2)");
		beamng.sendActiveObjectLua("input.event('axisy1', "+maxBrake+", 2)");
	}
	
	if(window.autoBlink) {
		window.finals.autoBlink = "ON";
	} else {
		window.finals.autoBlink = "OFF";
	}
	
	if(window.cruiseEnabled) {
		window.finals.cruiseControlState = "ON";
	} else {
		window.finals.cruiseControlState = "OFF";
	}
	//WARN CRASH 
	{
	if(streams.engineInfo[16] === false) {
		window.finals.engineState = "ON";
	} else {
		window.finals.engineState = "OFF";
	}
	
	
	if(steer > window.maxRange) {
		window.blink = "left";
	} else if(steer < -window.maxRange) {
		window.blink = "right";
	}
	if(window.autoBlink) {
	if(window.blink == "left" && window.blinkOn == false) {
		beamng.sendActiveObjectLua("electrics.toggle_left_signal()");
		window.blinkOn = true;
	}
	if(window.blink == "right" && window.blinkOn == false) {
		beamng.sendActiveObjectLua("electrics.toggle_right_signal()");
		window.blinkOn = true;
	}
	if(window.blink == "left" && steer == 0) {
		beamng.sendActiveObjectLua("electrics.toggle_left_signal()");
		window.blinkOn = false;
		window.blink = "off";
	}
	if(window.blink == "right" && steer == 0) {
		beamng.sendActiveObjectLua("electrics.toggle_right_signal()");
		window.blinkOn = false;
		window.blink = "off";
	}
	}

    if (warncrash > 260) {
		beamng.sendActiveObjectLua("electrics.toggle_warn_signal()");
		beamng.sendActiveObjectLua("drivetrain.canStart = false");
		beamng.sendActiveObjectLua("drivetrain.stopEngine()");
    }
	}
	
	
	
};
